/*
    Button.pde
    Copyright (C) 2011
    Authors: Arun I, Hari Prasad Gokul R, Prabhu P, Sravan M Baddepudi, Sudhakar M K, Suresh Kannan M
    email: theroarofthedragon@gmail.com

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
*/

//class to create a rectangular button

class Button
{
  //Position and dimensions of the button
  int xPos,yPos;
  int widthButton,heightButton;
  
  //Button properties
  String label;
  boolean locked=false;
  
  //Appearance attributes
  color baseColor=color(0);
  color highlightColor=color(125);
  color currentColor=baseColor,textColor=color(255,0,0);
  PFont font;
  
  Button(int xPos_,int yPos_,int widthButton_,int heightButton_,String label_,PFont font_)
  {
    //Storing construction values for later reference
    xPos=xPos_;
    yPos=yPos_;
    widthButton=widthButton_;
    heightButton=heightButton_;
    label=label_;
    font=font_;
    
    //draw button on the sketch
    drawButton();
  }

  void update() 
  {
    //set the color of the button according to locked status
    if (locked)
      currentColor = highlightColor;
    else
      currentColor = baseColor;
    //redraw button on the sketch
    drawButton();
  }

  boolean pressed() 
  {
    //function checks if the button has been pressed
    if(over())
    {
      locked = !locked;
      return true;
    } 
    else
      return false;
  }

  boolean over() 
  {
    //function checks if mouse is over the button
    if (mouseX >= xPos && mouseX <= xPos+widthButton && mouseY >= yPos && mouseY <= yPos+heightButton)
      return true; 
    else
      return false;
  }
  
  void drawButton() 
  {
    //draw rectangle for the button
    stroke(255);
    fill(currentColor);
    rect(xPos,yPos,widthButton,heightButton);
    
    //print button label
    fill(textColor);
    textAlign(CENTER,CENTER);
    textFont(font,14);
    text(label,xPos+widthButton/2,yPos+heightButton/2);
  }
}
